@@ -29,10 +29,10 @@
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/EntityRightsFilterModel>
 #include <Akonadi/EntityTreeModel>
+#include <Akonadi/History>
 #include <Akonadi/ItemModifyJob>
 #include <Akonadi/ItemMoveJob>
 #include <Akonadi/Monitor>
-#include <Akonadi/History>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 #include <EventViews/Prefs>
@@ -94,7 +94,7 @@ private Q_SLOTS:
         for (int i = start; i <= end; ++i) {
             // qCDebug(KORGANIZER_LOG) << "checking " << i << parent << mCheckableProxy->index(i, 0, parent).data().toString();
             const QModelIndex index = mCheckableProxy->index(i, 0, parent);
-            QMetaObject::invokeMethod(this, "setCheckState", Qt::QueuedConnection, QGenericReturnArgument(), Q_ARG(QPersistentModelIndex, index));
+            QMetaObject::invokeMethod(this, "setCheckState", Qt::QueuedConnection, Q_ARG(QPersistentModelIndex, index));
         }
     }
 
