@@ -16,13 +16,9 @@ public:
         TypeRole = Qt::UserRole + 1,
         TypeValueRole,
         DefaultRole,
+        EmailRole,
     };
-    enum Type {
-        Unknown = 0,
-        Home = 1,
-        Work = 2,
-        Other = 4
-    };
+    enum Type { Unknown = 0, Home = 1, Work = 2, Other = 4 };
     Q_ENUM(Type);
 
     EmailModel(QObject *parent = nullptr);
@@ -35,7 +31,7 @@ public:
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
 
-    Q_INVOKABLE void addEmail(const QString &email, Type type);
+    Q_INVOKABLE void addEmail(const QString &email, EmailModel::Type type);
     Q_INVOKABLE void deleteEmail(int row);
 
 Q_SIGNALS:
