@@ -26,30 +26,6 @@ function numberToString(number) {
     return i18n(number + numSuffixes[j]);
 }
 
-function secondsToReminderLabel(seconds) { // Gives prettified time
-
-    function numAndUnit(secs) {
-        if(secs >= (2 * 24 * 60 * 60))
-            return i18nc("%1 is 2 or more", "%1 days", Math.round(secs / (24*60*60))); // 2 days +
-            else if (secs >= (1 * 24 * 60 * 60))
-                return i18n("1 day");
-            else if (secs >= (2 * 60 * 60))
-                return i18nc("%1 is 2 or mores", "%1 hours", Math.round(secs / (60*60))); // 2 hours +
-                else if (secs >= (1 * 60 * 60))
-                    return i18n("1 hour");
-                else
-                    return i18n("%1 minutes", Math.round(secs / 60));
-    }
-
-    if (seconds < 0) {
-        return i18n("%1 before start of event", numAndUnit(seconds * -1));
-    } else if (seconds < 0) {
-        return i18n("%1 after start of event", numAndUnit(seconds));
-    } else {
-        return i18n("On event start");
-    }
-}
-
 function weeklyRecurrenceToString(recurrenceData) {
     let returnString = i18np("Every week", "Every %1 weeks", recurrenceData.frequency);
 
